@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
-our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2015-08-31'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,29 +38,38 @@ sub _scan_prereqs {
     };
     require File::Find;
     my @files;
-    find(
-        sub {
-            return unless -f;
-            return if check_backup_filename(filename=>$_);
-            push @files, "$File::Find::dir/$_";
-        },
-        (grep {-d} (
+
+    {
+        my @dirs = (grep {-d} (
             "lib", "bin", "script", "scripts",
             #"sample", "samples", "example", "examples" # decidedly not included
             #"share", # decidedly not included
-        ))
-    );
-    find(
-        sub {
-            return unless -f;
-            return if check_backup_filename(filename=>$_);
-            return unless /\.(t|pl|pm)$/;
-            push @files, "$File::Find::dir/$_";
-        },
-        (grep {-d} (
-            "t", "xt",
-        ))
-    );
+        ));
+        last unless @dirs;
+        find(
+            sub {
+                return unless -f;
+                return if check_backup_filename(filename=>$_);
+                push @files, "$File::Find::dir/$_";
+            },
+            @dirs
+        );
+    }
+
+    {
+        my @dirs = (grep {-d} ("t", "xt"));
+        last unless @dirs;
+        find(
+            sub {
+                return unless -f;
+                return if check_backup_filename(filename=>$_);
+                return unless /\.(t|pl|pm)$/;
+                push @files, "$File::Find::dir/$_";
+            },
+            @dirs
+        );
+    }
+
     my %res;
     for my $file (@files) {
         my $scanres = $scanner->scan_file($file);
@@ -326,7 +335,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.30 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-08-18.
+This document describes version 0.31 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-08-31.
 
 =head1 SYNOPSIS
 
@@ -402,7 +411,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-LintPr
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-LintPrereqs>.
+Source repository is at L<https://github.com/sharyanto/perl-App-LintPrereqs>.
 
 =head1 BUGS
 
